#!/bin/sh
# Makes static pages for each repository directory
# https://codemadness.org/git/stagit/file/example_create.sh.html

# path must be absolute.
stagitsrc="/opt/stagit"
reposdir="/srv/git"
stagitdir="/var/www/localhost/htdocs"

# copy style files.
cp "${stagitsrc}/favicon.png" "${stagitdir}/"
cp "${stagitsrc}/style.css" "${stagitdir}/"
cp "${stagitsrc}/logo.png" "${stagitdir}/"

cd "${stagitdir}"

# make index.
stagit-index "${reposdir}/"*/ > "${stagitdir}/index.html"

# make files per repo.
for dir in "${reposdir}/"*/; do
        # strip .git suffix.
        r=$(basename "${dir}")
        d=$(basename "${dir}" ".git")
        printf "%s... " "${d}"

        if [ -f "${reposdir}/${r}/git-daemon-export-ok" ]; then
          # create stagit static repo files for published repos.
          mkdir -p "${stagitdir}/${d}"
          cd "${stagitdir}/${d}" || continue

          # set post-recieve hook, owner and description
          cp -f "${stagitsrc}/example_post-receive.sh" "${reposdir}/${r}/hooks/post-receive"
          chmod +x "${reposdir}/${r}/hooks/post-receive"
          if [ ! -f "${reposdir}/${r}/owner" ]; then echo "in0rdr" > "${reposdir}/${r}/owner"; fi
          if [ ! -f "${reposdir}/${r}/description" ]; then echo "No description." > "${reposdir}/${r}/description"; fi
          if [ ! -f "${reposdir}/${r}/url" ]; then echo "https://git.in0rdr.ch/${r}" > "${reposdir}/${r}/url"; fi

          stagit -c ".cache" -u "https://git.in0rdr.ch/$d/" "${reposdir}/${r}"

          # symlinks
          ln -sf log.html index.html
          ln -sf ../style.css style.css
          ln -sf ../logo.png logo.png
          ln -sf ../favicon.png favicon.png
        else
          # unpublish repos.
          rm -rf "${stagitdir}/${d}"
        fi

        echo "done"
done

# ensure webserver permissions.
chown -R apache: "${stagitdir}"
chown -R apache: "${reposdir}"
