job "0x0" {
  datacenters = ["dc1"]

  group "server" {
    count = 1

    volume "0x0" {
      type = "csi"
      source = "0x0"
      access_mode = "multi-node-multi-writer"
      attachment_mode = "file-system"
    }

    volume "tls" {
      type = "csi"
      source = "certbot"
      access_mode = "multi-node-multi-writer"
      attachment_mode = "file-system"
    }

    network {
      port "fhost" {
        to = 8000
      }
      port "http" {
        static = 8998
      }
      port "https" {
        static = 8999
      }
    }

    # Prepare database migrations
    task "db-upgrade" {
      driver = "podman"

      volume_mount {
        volume = "0x0"
        destination = "/usr/src/app/0x0/data"
      }

      env {
        FLASK_APP = "fhost"
      }

      config {
        image = "127.0.0.1:5000/0x0:latest"
        force_pull = true
        command = "/bin/sh"
        args = ["-c", "flask db upgrade"]
      }

      resources {
        memory = 50
        memory_max = 128
        cpu = 200
      }

      lifecycle {
        hook = "prestart"
        sidecar = false
      }
    }

    task "nginx" {
      driver = "podman"

      config {
        image = "docker.io/library/nginx:stable-alpine"
        force_pull = true
        ports = ["https", "http"]
        volumes = [
          # mount the templated config from the task directory to the container
          "local/0x0.conf:/etc/nginx/conf.d/0x0.conf",
        ]
      }

      volume_mount {
        volume = "tls"
        destination = "/etc/letsencrypt"
      }

      template {
        destination = "${NOMAD_TASK_DIR}/0x0.conf"
        data = file("./templates/nginx.conf.tmpl")
      }

      resources {
        memory = 32
        memory_max = 64
        cpu    = 50
      }
    }

    task "fhost" {
      driver = "podman"

      config {
        image = "127.0.0.1:5000/0x0:latest"
        force_pull = true
        ports = ["fhost"]
        volumes = [
          # mount the templated config from the task directory to the container
          "local/config.py:/usr/src/app/0x0/instance/config.py",
          "local/index.html:/usr/src/app/0x0/templates/index.html",
        ]
      }

      volume_mount {
        volume = "0x0"
        destination = "/usr/src/app/0x0/data"
      }

      template {
        destination = "${NOMAD_TASK_DIR}/config.py"
        data = file("./templates/config.py.tmpl")
      }
      template {
        destination = "${NOMAD_TASK_DIR}/index.html"
        data = file("./templates/index.html.tmpl")
      }

      resources {
        memory = 64
        memory_max = 128
        cpu    = 200
      }
    }
  }
}
