job "ampache" {
  datacenters = ["dc1"]

  vault {}

  group "server" {
    count = 1

    volume "tls" {
      type = "csi"
      source = "certbot"
      access_mode = "multi-node-multi-writer"
      attachment_mode = "file-system"
    }
    volume "ampache" {
      type = "csi"
      source = "ampache"
      access_mode = "multi-node-multi-writer"
      attachment_mode = "file-system"
    }

    network {
      port "ampache" {
        to = 80
      }
      port "https" {
        to = 443
        static = 44391
      }
    }

    task "nginx" {
      driver = "podman"

      config {
        image = "docker.io/library/nginx:stable-alpine"
        ports = ["https"]
        volumes = [
          # mount the templated config from the task directory to the container
          "local/ampache.conf:/etc/nginx/conf.d/ampache.conf",
        ]
      }

      volume_mount {
        volume = "tls"
        destination = "/etc/letsencrypt"
      }

      template {
        destination = "${NOMAD_TASK_DIR}/ampache.conf"
        data = file("./templates/nginx.conf.tmpl")
      }

      resources {
        memory = 50
        memory_max = 256
        cpu    = 200
      }
    }

    task "ampache" {
      driver = "podman"

      config {
        image = "docker.io/ampache/ampache:nosql"
        force_pull = true
        ports = ["ampache"]
        volumes = [
          # mount the templated config from the task directory to the container
          "local/ampache.cfg.php:/var/www/config/ampache.cfg.php",
        ]
      }

      volume_mount {
        volume = "ampache"
        destination = "/media"
      }

      template {
        destination = "${NOMAD_TASK_DIR}/ampache.cfg.php"
        data = file("./templates/ampache.cfg.php.tmpl")
        uid = 33
        gid = 33
      }

      resources {
        memory = 50
        memory_max = 512
        cpu    = 300
      }
    }

  }
}
