# Create a Nomad variable certbot/domains with the list of domains:
#  cn1.example.com,san1.example.com,cn2.example.com,more.domains,..
#
# Also, store the letsencrypt email address in variable certbot/email

job "certbot" {
  datacenters = ["dc1"]
  type = "batch"

  periodic {
    crons = [
      "@daily"
    ]
  }

  group "certbot" {
    count = 1

    volume "certbot-data" {
      type = "csi"
      source = "certbot"
      access_mode = "multi-node-multi-writer"
      attachment_mode = "file-system"
    }

    network {
      port "http" {
        to = 80
        static = 8080
      }
      port "https" {
        to = 443
        static = 4433
      }
    }

    task "request" {
      driver = "podman"

      volume_mount {
        volume = "certbot-data"
        destination = "/etc/letsencrypt"
      }

      template {
        destination = "${NOMAD_TASK_DIR}/certbot-request.sh"
        data = file("./templates/certbot-request.sh.tmpl")
        perms = 755
      }

      config {
        image = "certbot/certbot:arm64v8-latest"
        force_pull = true
        ports = ["http", "https"]
        volumes = [
          "local/certbot-request.sh:/opt/certbot/tools/certbot-request.sh"
        ]
        entrypoint = ["./tools/certbot-request.sh"]
      }

      resources {
        memory = 50
        memory_max = 128
        cpu    = 300
      }
    }
  }
}
