job "cv" {
  datacenters = ["dc1"]

  group "server" {
    count = 1

    volume "tls" {
      type = "csi"
      source = "certbot"
      access_mode = "multi-node-multi-writer"
      attachment_mode = "file-system"
    }

    network {
      port "jekyll" {
        to = 4000
      }
      port "https" {
        static = 44361
      }
    }

    task "jekyll" {
      driver = "podman"

      config {
        image = "127.0.0.1:5000/jekyll-cv:latest"
        force_pull = true
        ports = ["jekyll"]
      }

      resources {
        memory = 50
        memory_max = 128
        cpu = 200
      }
    }

    task "nginx" {
      driver = "podman"

      config {
        image = "docker.io/library/nginx:stable-alpine"
        ports = ["https"]
        volumes = [
          # mount the templated config from the task directory to the container
          "local/cv.conf:/etc/nginx/conf.d/cv.conf",
        ]
      }

      volume_mount {
        volume = "tls"
        destination = "/etc/letsencrypt"
      }

      template {
        destination = "${NOMAD_TASK_DIR}/cv.conf"
        data = file("./templates/nginx.conf.tmpl")
      }

      resources {
        memory = 50
        memory_max = 128
        cpu    = 200
      }
    }
  }
}
