job "freshrss" {
  datacenters = ["dc1"]

  group "server" {
    count = 1

    volume "tls" {
      type = "csi"
      source = "certbot"
      access_mode = "multi-node-multi-writer"
      attachment_mode = "file-system"
    }
    volume "freshrss-data" {
      type = "csi"
      source = "freshrss-data"
      access_mode = "multi-node-multi-writer"
      attachment_mode = "file-system"
    }
    volume "freshrss-ext" {
      type = "csi"
      source = "freshrss-ext"
      access_mode = "multi-node-multi-writer"
      attachment_mode = "file-system"
    }

    network {
      port "server" {
        to = 80
      }
      port "https" {
        static = 44403
      }
    }

    task "nginx" {
      driver = "podman"

      config {
        image = "docker.io/library/nginx:stable-alpine"
        ports = ["https"]
        volumes = [
          # mount the templated config from the task directory to the container
          "local/freshrss.conf:/etc/nginx/conf.d/snibox.conf",
        ]
      }

      volume_mount {
        volume = "tls"
        destination = "/etc/letsencrypt"
      }

      template {
        destination = "${NOMAD_TASK_DIR}/freshrss.conf"
        data = file("./templates/nginx.conf.tmpl")
      }

      resources {
        memory = 50
        memory_max = 128
        cpu    = 100
      }
    }

    task "server" {
      driver = "podman"

      env {
	# https://github.com/FreshRSS/FreshRSS/blob/edge/Docker/freshrss/example.env
        # https://github.com/FreshRSS/FreshRSS/blob/edge/Docker/README.md#environment-variables
	BASE_URL = "https://rss.in0rdr.ch"
        TZ = "Europe/Zurich"
        CRON_MIN = "*/20"
      }

      config {
        image = "docker.io/freshrss/freshrss:latest"
        force_pull = true
        ports = ["server"]
      }

      volume_mount {
        volume = "freshrss-data"
        destination = "/var/www/FreshRSS/data"
      }
      volume_mount {
        volume = "freshrss-ext"
        destination = "/var/www/FreshRSS/extensions"
      }

      resources {
        memory = 150
        memory_max = 300
        cpu    = 300
      }
    }
  }
}
