job "git" {
  datacenters = ["dc1"]

  priority = 80

  group "server" {
    count = 1

    volume "git" {
      type = "csi"
      source = "git"
      access_mode = "multi-node-multi-writer"
      attachment_mode = "file-system"
    }
    volume "stagit" {
      type = "csi"
      source = "stagit"
      access_mode = "multi-node-multi-writer"
      attachment_mode = "file-system"
    }
    volume "tls" {		
      type = "csi"		
      source = "certbot"		
      access_mode = "multi-node-multi-writer"		
      attachment_mode = "file-system"		
    }

    network {
      port "stagit" {
        to = 443
        static = 44328
      }
      port "smarthttp" {
        to = 443
        static = 44318
      }
    }

    task "smarthttp" {
      driver = "podman"

      config {
        image = "127.0.0.1:5000/git:latest"
        force_pull = true
        ports = ["smarthttp"]
        volumes = [
          # mount the templated config from the task directory to the container
          "local/smarthttp.conf:/etc/apache2/conf.d/smarthttp.conf",
        ]
      }

      template {
        destination = "${NOMAD_TASK_DIR}/smarthttp.conf"
        data = file("./templates/smarthttp.conf.tmpl")
      }

      volume_mount {
        volume = "git"
        destination = "/srv/git"
      }
      volume_mount {
        volume = "stagit"
        destination = "/var/www/localhost/htdocs"
      }
      volume_mount {		
        volume = "tls"		
        destination = "/etc/letsencrypt"		
      }

      resources {
        memory = 32
        memory_max = 64
        cpu    = 100
      }
    }

    task "stagit" {
      driver = "podman"

      config {
        image = "127.0.0.1:5000/git:latest"
        force_pull = true
        ports = ["stagit"]
        volumes = [
          # mount the templated config from the task directory to the container
          "local/stagit.conf:/etc/apache2/conf.d/stagit.conf",
        ]
      }

      template {
        destination = "${NOMAD_TASK_DIR}/stagit.conf"
        data = file("./templates/stagit.conf.tmpl")
      }

      volume_mount {
        volume = "git"
        destination = "/srv/git"
      }
      volume_mount {
        volume = "stagit"
        destination = "/var/www/localhost/htdocs"
      }
      volume_mount {		
        volume = "tls"		
        destination = "/etc/letsencrypt"		
      }

      resources {
        memory = 32
        memory_max = 64
        cpu    = 100
      }
    }
  }
}
