# - https://docs.kanboard.org/v1/admin/docker
# - https://github.com/kanboard/kanboard/blob/main/docker-compose.yml

job "kanboard" {
  datacenters = ["dc1"]

  priority = 80

  vault {}

  group "server" {
    count = 1

    volume "tls" {
      type = "csi"
      source = "certbot"
      access_mode = "multi-node-multi-writer"
      attachment_mode = "file-system"
    }
    volume "kanboard" {
      type = "csi"
      source = "kanboard"
      access_mode = "multi-node-multi-writer"
      attachment_mode = "file-system"
    }

    network {
      port "kanboard" {
        to = 80
      }
      port "https" {
        static = 44400
      }
    }

    task "kanboard" {
      driver = "podman"

      config {
        image = "ghcr.io/kanboard/kanboard:nightly"
        force_pull = true
        ports = ["kanboard"]
        volumes = [
          # mount the templated config from the task directory to the container
          "local/kanboard.php:/var/www/app/data/config.php",
        ]
      }

      volume_mount {
        volume = "kanboard"
        destination = "/var/www/app/data"
      }

      template {
        destination = "${NOMAD_TASK_DIR}/kanboard.php"
        data = file("./templates/kanboard.php.tmpl")
      }

      resources {
        memory = 50
        memory_max = 256
        cpu    = 200
      }
    }

    task "nginx" {
      driver = "podman"

      config {
        image = "docker.io/library/nginx:stable-alpine"
        ports = ["https"]
        volumes = [
          # mount the templated config from the task directory to the container
          "local/kanboard.conf:/etc/nginx/conf.d/kanboard.conf",
        ]
      }

      volume_mount {
        volume = "tls"
        destination = "/etc/letsencrypt"
      }

      template {
        destination = "${NOMAD_TASK_DIR}/kanboard.conf"
        data = file("./templates/nginx.conf.tmpl")
      }

      resources {
        memory = 50
        memory_max = 256
        cpu    = 200
      }
    }

  }
}
