# https://github.com/picosh/git-pr/blob/main/docker-compose.prod.yml
job "pico" {
  datacenters = ["dc1"]

  priority = 80

  group "server" {
    count = 1

    volume "pico" {
      type = "csi"
      source = "pico"
      access_mode = "multi-node-multi-writer"
      attachment_mode = "file-system"
    }
    volume "tls" {
      type = "csi"
      source = "certbot"
      access_mode = "multi-node-multi-writer"
      attachment_mode = "file-system"
    }

    network {
      port "web" {
        to = 3000
      }
      port "ssh" {
        to = 2222
        static = 44405
      }
      port "https" {
        static = 44406
      }
    }

    task "web" {
      driver = "podman"

      config {
        image = "ghcr.io/picosh/pico/git-web:latest"
        ports = ["web"]
        volumes = [
          # mount the templated config from the task directory to the container
          "local/git-pr.toml:/app/git-pr.toml",
        ]
      }

      template {
        destination = "${NOMAD_TASK_DIR}/.env"
        data = file("./templates/.env.tmpl")
        env = true
      }

      template {
        destination = "${NOMAD_TASK_DIR}/git-pr.toml"
        data = file("./templates/git-pr.toml.tmpl")
      }

      volume_mount {
        volume = "pico"
        destination = "/app/data"
      }

      resources {
        memory = 256
        memory_max = 512
        cpu    = 250
      }
    }

    task "ssh" {
      driver = "podman"

      config {
        image = "ghcr.io/picosh/pico/git-ssh:latest"
        ports = ["ssh"]
        volumes = [
          # mount the templated config from the task directory to the container
          "local/git-pr.toml:/app/git-pr.toml",
        ]
      }

      template {
        destination = "${NOMAD_TASK_DIR}/.env"
        data = file("./templates/.env.tmpl")
        env = true
      }

      template {
        destination = "${NOMAD_TASK_DIR}/git-pr.toml"
        data = file("./templates/git-pr.toml.tmpl")
      }

      volume_mount {
        volume = "pico"
        destination = "/app/data"
      }

      resources {
        memory = 256
        memory_max = 512
        cpu    = 250
      }
    }

    task "nginx" {
      driver = "podman"

      config {
        image = "docker.io/library/nginx:stable-alpine"
        ports = ["https"]
        volumes = [
          # mount the templated config from the task directory to the container
          "local/pico.conf:/etc/nginx/conf.d/pico.conf",
        ]
      }

      volume_mount {
        volume = "tls"
        destination = "/etc/letsencrypt"
      }

      template {
        destination = "${NOMAD_TASK_DIR}/pico.conf"
        data = file("./templates/nginx.conf.tmpl")
      }

      resources {
        memory = 50
        memory_max = 128
        cpu    = 200
      }
    }
  }
}
