# https://git.pleroma.social/pleroma/pleroma-docker-compose

job "pleroma" {
  datacenters = ["dc1"]

  vault {}

  group "server" {
    count = 1

    volume "tls" {
      type = "csi"
      source = "certbot"
      access_mode = "multi-node-multi-writer"
      attachment_mode = "file-system"
    }
    volume "pleroma" {
      type = "csi"
      source = "pleroma"
      access_mode = "multi-node-multi-writer"
      attachment_mode = "file-system"
    }

    network {
      port "http" {
        to = 4000
      }
      port "https" {
        static = 44393
      }
    }

    task "nginx" {
      driver = "podman"

      config {
        image = "docker.io/library/nginx:stable-alpine"
        ports = ["https"]
        volumes = [
          # mount the templated config from the task directory to the container
          "local/pleroma.conf:/etc/nginx/conf.d/pleroma.conf",
        ]
      }

      volume_mount {
        volume = "tls"
        destination = "/etc/letsencrypt"
      }

      template {
        destination = "${NOMAD_TASK_DIR}/pleroma.conf"
        data = file("./templates/nginx.conf.tmpl")
      }

      resources {
        memory = 50
        memory_max = 256
        cpu    = 200
      }
    }

    task "pleroma" {
      driver = "podman"

      config {
        image = "git.pleroma.social:5050/pleroma/pleroma:latest"
        force_pull = true
        ports = ["http"]
      }

      volume_mount {
        volume = "pleroma"
        destination = "/var/lib/pleroma/uploads"
      }

      template {
        destination = "${NOMAD_TASK_DIR}/pleroma.env"
        data = file("./templates/pleroma.env.tmpl")
        env = true
      }

      resources {
        memory = 512
        memory_max = 1024
        cpu    = 500
      }
    }

  }
}
