job "snibox" {
  datacenters = ["dc1"]

  vault {}

  group "server" {
    count = 1

    volume "tls" {
      type = "csi"
      source = "certbot"
      access_mode = "multi-node-multi-writer"
      attachment_mode = "file-system"
    }
    volume "snibox" {
      type = "csi"
      source = "snibox"
      access_mode = "multi-node-multi-writer"
      attachment_mode = "file-system"
    }

    network {
      port "server" {
        to = 3000
      }
      port "https" {
        static = 44392
      }
    }

    task "nginx" {
      driver = "podman"

      config {
        image = "docker.io/library/nginx:stable-alpine"
        ports = ["https"]
        volumes = [
          # mount the templated config from the task directory to the container
          "local/snibox.conf:/etc/nginx/conf.d/snibox.conf",
        ]
      }

      volume_mount {
        volume = "tls"
        destination = "/etc/letsencrypt"
      }

      template {
        destination = "${NOMAD_TASK_DIR}/snibox.conf"
        data = file("./templates/nginx.conf.tmpl")
      }

      resources {
        memory = 50
        memory_max = 128
        cpu    = 100
      }
    }

    task "server" {
      driver = "podman"

      env {
        RAILS_LOG_TO_STDOUT = true
        # https://github.com/snibox/snibox/issues/25
        RAILS_SERVE_STATIC_FILES = true
        DB_NAME = "snibox"
        DB_USER = "snibox"
        DB_HOST = "postgres.lan"
      }

      template {
        # render sensitive env vars in a template from Vault secrets
        env = true
        destination = "${NOMAD_SECRETS_DIR}/env"
        data = <<EOT
DB_PASS = "{{with secret "kv/snibox"}}{{index .Data.data.db_password}}{{end}}"
SECRET_KEY_BASE = "{{with secret "kv/snibox"}}{{index .Data.data.secret_key_base}}{{end}}"
EOT
      }

      config {
        image = "127.0.0.1:5000/snibox:latest"
        force_pull = true
        command = "/bin/sh"
        args = ["-c", "rm -rf tmp/pids && ./bin/rails s -p 3000 -b '0.0.0.0'"]
        ports = ["server"]
      }

      volume_mount {
        volume = "snibox"
        destination = "/app/public"
      }

      resources {
        memory = 50
        memory_max = 256
        cpu    = 200
      }
    }
  }
}
