# https://snikket.org/service/resources/docker-compose.yml

job "snikket" {
  datacenters = ["dc1"]

  vault {}

  group "server" {
    count = 1

    volume "tls" {
      type = "csi"
      source = "certbot"
      access_mode = "multi-node-multi-writer"
      attachment_mode = "file-system"
    }
    volume "snikket" {
      type = "csi"
      source = "snikket"
      access_mode = "multi-node-multi-writer"
      attachment_mode = "file-system"
    }

    network {
      port "portal" {}
      port "prosody" {
        static = 44409
      }
      port "proxy" {
        static = 44408
      }
    }

    task "proxy" {
      driver = "podman"

      config {
        image = "docker.io/library/nginx:stable-alpine"
        ports = ["proxy"]
        volumes = [
          # mount the templated config from the task directory to the container
          "local/snikket.conf:/etc/nginx/conf.d/snikket.conf",
          "local/snikket-common.conf:/etc/nginx/snippets/snikket-common.conf",
        ]
      }

      template {
        destination = "${NOMAD_TASK_DIR}/snikket.conf"
        data = file("./templates/nginx.conf.tmpl")
      }
      template {
        destination = "${NOMAD_TASK_DIR}/snikket-common.conf"
        data = file("./templates/nginx-snippets.conf.tmpl")
      }

      template {
        destination = "${NOMAD_TASK_DIR}/snikket.env"
        data = file("./templates/snikket.env.tmpl")
        env = true
      }

      volume_mount {
        volume = "snikket"
        destination = "/snikket"
      }
      volume_mount {
        volume = "tls"
        destination = "/snikket/letsencrypt"
      }

      resources {
        memory = 256
        memory_max = 512
        cpu    = 250
      }
    }

    task "portal" {
      driver = "podman"

      config {
        image = "docker.io/snikket/snikket-web-portal:stable"
        ports = ["portal"]
      }

      volume_mount {
        volume = "snikket"
        destination = "/snikket"
      }

      template {
        destination = "${NOMAD_TASK_DIR}/snikket.env"
        data = file("./templates/snikket.env.tmpl")
        env = true
      }

      resources {
        memory = 256
        memory_max = 512
        cpu    = 250
      }
    }

    task "snikket" {
      driver = "podman"

      config {
        image = "docker.io/snikket/snikket-server:stable"
        ports = ["prosody"]
      }

      volume_mount {
        volume = "snikket"
        destination = "/snikket"
      }
      # Snikket prosody service waits for certificates
      volume_mount {
        volume = "tls"
        destination = "/snikket/letsencrypt"
      }

      template {
        destination = "${NOMAD_TASK_DIR}/snikket.env"
        data = file("./templates/snikket.env.tmpl")
        env = true
      }

      resources {
        memory = 256
        memory_max = 512
        cpu    = 200
      }
    }
  }
}
