variable "api_addr" {
  type        = string
  description = "Vault domain name (API address)"
}

variable "user" {
  type        = string
  description = "Unix user to launch the job with. Needs sudo privileges to reload vault and copy certificates."
}

job "vault-tls" {
  datacenters = ["dc1"]
  type = "batch"

  periodic {
    crons = [
      "@daily"
    ]
  }

  group "vault-tls" {
    count = 5
    constraint {
      distinct_hosts = true
    }

    volume "tls" {
      type = "csi"
      source = "certbot"
      access_mode = "multi-node-multi-writer"
      attachment_mode = "file-system"
    }

    task "vault-tls" {
      driver = "exec"
      user = var.user

      template {
        destination = "${NOMAD_TASK_DIR}/vault-tls.sh"
        data = file("./templates/vault-tls.sh.tmpl")
        perms = 755
      }

      config {
        pid_mode = "host" # need to send SIGHUP to vault to reload config file
        command = "${NOMAD_TASK_DIR}/vault-tls.sh"
        args = [var.api_addr]
      }

      volume_mount {
        volume = "tls"
        destination = "/etc/letsencrypt"
      }

      resources {
        memory = 16
        memory_max = 32
        cpu    = 20
      }
    }
  }
}
