job "public-registry" {
  datacenters = ["dc1"]
  type = "service"
  priority = 85

  group "server" {
    count = 5

    volume "registry-data" {
      type = "csi"
      source = "registry"
      access_mode = "multi-node-multi-writer"
      attachment_mode = "file-system"
    }
    volume "tls" {
      type = "csi"
      source = "certbot"
      access_mode = "multi-node-multi-writer"
      attachment_mode = "file-system"
    }

    network {
      port "https" {
        to = 5000
        static = 5050
      }
    }

    task "registry" {
      driver = "podman"

      volume_mount {
        volume = "registry-data"
        destination = "/var/lib/registry"
      }
      volume_mount {
        volume = "tls"
        destination = "/etc/letsencrypt"
      }

      vault {
        policies = ["public-registry"]
        change_mode = "noop"
      }

      template {
        destination = "${NOMAD_SECRETS_DIR}/htpasswd"
        # https://www.nomadproject.io/docs/job-specification/template#vault-kv-api-v2
        data = "{{ with secret \"kv/registry\" }}{{ .Data.data.htpasswd }}{{end}}"
      }

      template {
        destination = "${NOMAD_TASK_DIR}/config.yml"
        data = file("./templates/config.yml.tmpl")
      }

      config {
        image = "registry:latest"
        force_pull = true
        ports = ["https"]
        volumes = [
          # mount the templated config from the task directory to the container
          "local/config.yml:/etc/docker/registry/config.yml",
        ]
      }

      resources {
        memory = 64
        cpu    = 100
      }
    }
  }
}
