job "snapshot" {
  datacenters = ["dc1"]
  type = "batch"

  vault {
    role = "snapshot"
    # export VAULT_TOKEN for use in snapshot.sh script
    env = true
  }

  parameterized {
    payload = "forbidden"
    meta_required = ["service"]
  }

  periodic {
    # At minute 12 past every hour
    crons = [
      "12 */1 * * *"
    ]
    # prevents "volume max claim reached" on CSI volume
    prohibit_overlap = true
  }

  group "snapshot" {
    count = 1

    volume "nomad-snapshots" {
      type = "csi"
      source = "nomad-snapshots"
      access_mode = "multi-node-multi-writer"
      attachment_mode = "file-system"
    }

    network {
      mode = "host"
    }

    task "snapshot-save" {
      driver = "exec"

      env {
        NOMAD_ADDR = "https://127.0.0.1:4646"
        # only save variables from default namespace
        NOMAD_NAMESPACE = "default"
        NOMAD_SKIP_VERIFY = 1
        VAULT_SKIP_VERIFY = 1
      }

      template {
        destination = "${NOMAD_TASK_DIR}/snapshot.sh"
        data = file("./templates/snapshot.sh.tmpl")
        perms = 755
      }

      config {
        command = "${NOMAD_TASK_DIR}/snapshot.sh"
        # Note: This meta variable (the parametrized service name)
        # could also be directly accessed inside the template
        args = [NOMAD_META_SERVICE]
      }

      volume_mount {
        volume = "nomad-snapshots"
        destination = "/mnt"
      }

      resources {
        memory = 128
        cpu    = 200
      }
    }
  }
}
